@@ -26,9 +26,11 @@ module.exports = {
         "config-title",
         "config-colors",
         "config-templates",
+        "config-secondary-prompt",
         "config-transient",
+        "config-line-error",
         "config-tooltips",
-        "config-fonts"
+        "config-fonts",
       ],
     },
     {
@@ -44,6 +46,8 @@ module.exports = {
         "brewfather",
         "command",
         "crystal",
+        "cf",
+        "cftarget",
         "dart",
         "dotnet",
         "executiontime",
