@@ -172,7 +172,7 @@ func TestColorMigration(t *testing.T) {
 		if tc.Background {
 			segment.Properties[colorBackground] = true
 		}
-		segment.migrateColorOverride(tc.Property, tc.Template)
+		segment.migrateColorOverride(tc.Property, tc.Template, tc.Background)
 		templates := segment.ForegroundTemplates
 		if tc.Background {
 			templates = segment.BackgroundTemplates
@@ -221,7 +221,7 @@ func TestSegmentTemplateMigration(t *testing.T) {
 		},
 		{
 			Case:     "EXIT - No exit code",
-			Expected: "  ",
+			Expected: " {{ if gt .Code 0 }}FAIL{{ else }}SUCCESS{{ end }} ",
 			Type:     EXIT,
 			Props: properties.Map{
 				"display_exit_code": false,
@@ -229,6 +229,19 @@ func TestSegmentTemplateMigration(t *testing.T) {
 				"error_icon":        "FAIL",
 			},
 		},
+		{
+			Case:     "EXIT - No spaces",
+			Expected: "{{ if gt .Code 0 }}💩{{ else }}🌵{{ end }}",
+			Type:     EXIT,
+			Props: properties.Map{
+				"prefix":            "",
+				"postfix":           "",
+				"display_exit_code": false,
+				"always_enabled":    true,
+				"success_icon":      "🌵",
+				"error_icon":        "💩",
+			},
+		},
 		{
 			Case:     "EXIT - Always numeric",
 			Expected: " {{ if gt .Code 0 }}FAIL {{ .Code }}{{ else }}SUCCESS{{ end }} ",
