@@ -26,10 +26,13 @@ type Segment struct {
 	LeadingDiamond      string         `json:"leading_diamond,omitempty"`
 	TrailingDiamond     string         `json:"trailing_diamond,omitempty"`
 	Properties          properties.Map `json:"properties,omitempty"`
-	writer              SegmentWriter
-	text                string
-	active              bool
-	env                 environment.Environment
+
+	writer          SegmentWriter
+	text            string
+	active          bool
+	env             environment.Environment
+	backgroundCache string
+	foregroundCache string
 }
 
 // SegmentTiming holds the timing context for a segment
@@ -151,6 +154,10 @@ const (
 	HASKELL SegmentType = "haskell"
 	// UI5 Tooling segment
 	UI5TOOLING SegmentType = "ui5tooling"
+	// Cloud Foundry segment
+	CF SegmentType = "cf"
+	// Cloud Foundry logged in target
+	CFTARGET SegmentType = "cftarget"
 )
 
 func (segment *Segment) shouldIncludeFolder() bool {
@@ -214,11 +221,17 @@ func (segment *Segment) shouldInvokeWithTip(tip string) bool {
 }
 
 func (segment *Segment) foreground() string {
-	return segment.getColor(segment.ForegroundTemplates, segment.Foreground)
+	if len(segment.foregroundCache) == 0 {
+		segment.foregroundCache = segment.getColor(segment.ForegroundTemplates, segment.Foreground)
+	}
+	return segment.foregroundCache
 }
 
 func (segment *Segment) background() string {
-	return segment.getColor(segment.BackgroundTemplates, segment.Background)
+	if len(segment.backgroundCache) == 0 {
+		segment.backgroundCache = segment.getColor(segment.BackgroundTemplates, segment.Background)
+	}
+	return segment.backgroundCache
 }
 
 func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error {
@@ -269,6 +282,8 @@ func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error
 		IPIFY:         &segments.IPify{},
 		HASKELL:       &segments.Haskell{},
 		UI5TOOLING:    &segments.UI5Tooling{},
+		CF:            &segments.Cf{},
+		CFTARGET:      &segments.CfTarget{},
 	}
 	if segment.Properties == nil {
 		segment.Properties = make(properties.Map)
